==> gammaray_2.0.1.orig.tar.xz: gammaray-2.0.1/ui/tools/mimetypes/mimetypeswidget.cpp <==
/*
  mimetypeswidget.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "mimetypeswidget.h"
#include "ui_mimetypeswidget.h"

#include <ui/deferredresizemodesetter.h>
#include <common/objectbroker.h>

#include <kde/krecursivefilterproxymodel.h>

using namespace GammaRay;

MimeTypesWidget::MimeTypesWidget(QWidget *parent)
  : QWidget(parent), ui(new Ui::MimeTypesWidget)
{
  ui->setupUi(this);

  QSortFilterProxyModel *proxy = new KRecursiveFilterProxyModel(this);
  proxy->setDynamicSortFilter(true);
  proxy->setSourceModel(ObjectBroker::model("com.kdab.GammaRay.MimeTypeModel"));
  ui->mimeTypeView->setModel(proxy);
  new DeferredResizeModeSetter(ui->mimeTypeView->header(), 0, QHeaderView::ResizeToContents);
  new DeferredResizeModeSetter(ui->mimeTypeView->header(), 1, QHeaderView::ResizeToContents);
  ui->mimeTypeView->sortByColumn(0, Qt::AscendingOrder);
  ui->searchLine->setProxy(proxy);
}

MimeTypesWidget::~MimeTypesWidget()
{
}

==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/ui/tools/mimetypes/mimetypeswidget.cpp <==
/*
  mimetypeswidget.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "mimetypeswidget.h"
#include "ui_mimetypeswidget.h"

#include <ui/deferredresizemodesetter.h>
#include <ui/searchlinecontroller.h>

#include <common/objectbroker.h>

using namespace GammaRay;

MimeTypesWidget::MimeTypesWidget(QWidget *parent)
  : QWidget(parent), ui(new Ui::MimeTypesWidget)
{
  ui->setupUi(this);

  auto model = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.MimeTypeModel"));
  ui->mimeTypeView->setModel(model);
  new DeferredResizeModeSetter(ui->mimeTypeView->header(), 0, QHeaderView::ResizeToContents);
  new DeferredResizeModeSetter(ui->mimeTypeView->header(), 1, QHeaderView::ResizeToContents);
  ui->mimeTypeView->sortByColumn(0, Qt::AscendingOrder);
  new SearchLineController(ui->searchLine, model);
}

MimeTypesWidget::~MimeTypesWidget()
{
}
